@@ -1,3 +1,7 @@
+"""
+Code based on https://github.com/18sg/undergroundStatus/blob/master/undergroundStatus.py
+"""
+
 from time import time
 import requests
 import xml.etree.ElementTree as et
@@ -10,6 +14,7 @@ class Status(object):
     """
     def __init__(self):
         self.update_url = "http://cloud.tfl.gov.uk/TrackerNet/LineStatus"
+        self.xmlns = "{http://webservices.lul.co.uk/}"
         self.lines = {}
         self.last_update = 0
         self.last_request = None
@@ -22,15 +27,20 @@ class Status(object):
 
         root = et.fromstring(self.last_request.content)
         for child in root:
-            current_line = Line()
-            current_line.name = child[1].get('Name')
-            current_line.status_code = child[2].get('ID')
-            self.lines[current_line.name] = current_line
+            line = Line()
+            line.id = child.find(self.xmlns + 'Line').get('ID')
+            line.name = child.find(self.xmlns + 'Line').get('Name')
+            line.status_code = child.find(self.xmlns + 'Status').get('ID')
+            line.status_details = child.get('StatusDetails')
+            line.css_class = child.find(self.xmlns + 'Status').get('CssClass')
+            line.description = child.find(self.xmlns + 'Status').get('Description')
+            line.is_active = child.find(self.xmlns + 'Status').get('IsActive')
+            self.lines[line.name] = line
 
     def get_status(self, line_code):
         self.update_status()
         if line_code in self.lines:
-            return self.lines[line_code].status_code
+            return self.lines[line_code]
         else:
             return None
 
